import axios from 'axios'
import { Message } from 'element-ui'
 
import { getToken } from '@/utils/auth'

import qs from 'qs'
// create an axios instance
const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API, // url = base url + request url
  // withCredentials: true, // send cookies when cross-domain requests
  timeout: 5000, // request timeout
  withCredentials: true
})


// request interceptor
service.interceptors.request.use(
  config => {
    // do something before request is sent
    config.headers['Content-Type'] = 'application/x-www-form-urlencoded';
 
    config.headers['api-token'] = getToken() || ''
 
    var formData = new FormData()

    for(let i in config.data) {
      formData.append(i, JSON.stringify(config.data[i]))
    }

    config.data = formData

    return config
  },
  error => {
    // do something with request error
    console.log(error) // for debug
    return Promise.reject(error)
  }
)

// response interceptor
service.interceptors.response.use(
  /**
   * If you want to get http information such as headers or status
   * Please return  response => response
   */

  /**
   * Determine the request status by custom code
   * Here is just an example
   * You can also judge the status by HTTP Status Code
   */
  response => {
    const res = response.data
    console.log(res)
    // if the custom code is not 20000, it is judged as an error.
    if (res.error_code !== 0) {
      Message({
        message: res.message || 'Error',
        type: 'error',
        duration: 5 * 1000
      })
      return Promise.reject(new Error(res.message || 'Error'))
    } else {
      return res
    }
  },
  error => {

    console.log(error)
    // const errorMsg = error.response.data.msg
 
    // 特殊处理401，需要验证手机号
    if (error.response.data.code === 401) {
      return error.response.data
    }
    // 登录超时，重新登录
    if (error.response.data.code === 403) {
      store.dispatch('user/resetToken').then(() => {
        location.reload()
      })
      Message({
        message: '登录超时，请重新登录',
        type: 'error',
        duration: 5 * 1000
      })
      return
    }

    Message({
      message: errorMsg ?? error,
      type: 'error',
      duration: 5 * 1000
    })
    return Promise.reject(error)
  }
)

export default service
